@@ -12,14 +12,15 @@ use Mojo::URL;
 use Scalar::Util qw( weaken );
 use Mojo::Base 'Mojolicious';
 use File::HomeDir ();
-use Carp qw( cluck croak carp );
+use Carp qw( croak carp );
 use Clustericious;
 use Clustericious::Controller;
 use Clustericious::Config;
 use Clustericious::Commands;
+use Path::Class::Dir;
 
 # ABSTRACT: Clustericious app base class
-our $VERSION = '1.22'; # VERSION
+our $VERSION = '1.23'; # VERSION
 
 
 has commands => sub {
@@ -39,7 +40,7 @@ sub startup {
 
     # this is questionable
     my $home = $self->home;
-    $self->renderer->paths([ $home->rel_dir('templates') ]);
+    $self->renderer->paths([ Path::Class::Dir->new($home)->subdir('templates')->stringify ]);
 
     $self->plugin('CommonRoutes');
     $self->plugin('AutodataHandler');
@@ -183,7 +184,7 @@ Clustericious::App - Clustericious app base class
 
 =head1 VERSION
 
-version 1.22
+version 1.23
 
 =head1 SYNOPSIS
 
