@@ -20,7 +20,7 @@ use Carp qw( carp );
 use Mojo::Util qw( monkey_patch );
 
 # ABSTRACT: Construct command line and perl clients for RESTful services.
-our $VERSION = '1.22'; # VERSION
+our $VERSION = '1.23'; # VERSION
 
 
 has server_url => '';
@@ -146,7 +146,7 @@ sub errorstring {
     my $self = shift;
     WARN "Missing response in ua object" unless $self->res;
     return unless $self->res;
-    return if $self->res->code && $self->res->is_status_class(200);
+    return if $self->res->code && $self->res->is_success;
     my $error = $self->res->error;
     if(defined $error->{advice})
     {
@@ -419,7 +419,7 @@ sub _doit {
         return $self->_doit($meta ? $meta : (), @_);
     }
 
-    if ($res->is_status_class(200)) {
+    if ($res->is_success) {
         TRACE "Got response : ".$res->to_string;
         my $content_type = $res->headers->content_type || do {
             WARN "No content-type from "._sanitize_url($url);
@@ -636,7 +636,7 @@ Clustericious::Client - Construct command line and perl clients for RESTful serv
 
 =head1 VERSION
 
-version 1.22
+version 1.23
 
 =head1 SYNOPSIS
 
